package com.rowem.ifree.sdk.sample;

import android.content.Intent;
import android.os.Bundle;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import com.rowem.ifree.sdk.exception.SDKInitializedException;
import com.rowem.ifree.sdk.ifreeSDK;
import com.rowem.ifree.sdk.model.LoginResult;

import java.util.UUID;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class MainActivity extends AppCompatActivity {

    private ifreeSDK sdk;

    private TextView tvLog;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        try {
            sdk = ifreeSDK.getInstance();
        } catch (SDKInitializedException e) {
            // SDK 초기화 오류
            e.printStackTrace();
        }

        tvLog = findViewById(R.id.tv_log);

        findViewById(R.id.bt_login).setOnClickListener(view -> {
            login(makeStatToken());
        });
    }
    private void login(final String statToken){
        if(sdk == null) return;

        // 로그인 요청
        sdk.login(MainActivity.this, statToken, (login, errorInfo) -> {
            if(login!=null){
                if(!statToken.equalsIgnoreCase(login.getStatToken())){
                    // 로그인 요청시 전달한 상태토큰 불일치
                    appendLog("Login E -> StatToken Not Match ");
                    return;
                }

                // TODO: 성공 처리 - LoginResult 객체 전달
                appendLog(String.format("Login Success -> %s", login.toString()));

                login(login);
            }else{
                // TODO: 실패 처리 - ErrorInfo 객체 전달
                appendLog(String.format("E -> %s %s(%s)", errorInfo.name(), errorInfo.getCode(), errorInfo.getErrorCode() ));
            }
        });
    }

    private String makeStatToken(){
        // Stat Token 생성 (임의)
        return UUID.randomUUID().toString();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        // SDK 내역 여부 체크
        if(sdk!=null && sdk.handleResult(requestCode, resultCode, data)){
            return;
        }
    }

    private void appendLog(final String msg){
        if(tvLog == null || msg == null) return;

        runOnUiThread(()-> tvLog.append("\n"+msg));
    }

    private void login(LoginResult login){
        // 제휴사 서비스 가입 또는 로그인 진행
        Server.getInstance(this).callApiLogin(login.getPtnToken(), sdk.getClientId() , new Callback<RespLogin>() {
            @Override
            public void onResponse(Call<RespLogin> call, Response<RespLogin> response) {
                if(response.isSuccessful() && response.body()!=null){
                    RespLogin res = response.body();

                    if("0000".equals(res.getCode())){
                        appendLog(String.format("APP: Login Success(%s)", response.body()));
                    }else{
                        appendLog(String.format("APP: Login Failed -> (%s)%s", res.getCode(), res.getMessage()));
                    }
                }else{
                    appendLog(String.format("APP: Login Failed -> (%d)%s", response.code(), response.message()));
                }
            }

            @Override
            public void onFailure(Call<RespLogin> call, Throwable t) {
                appendLog(String.format("APP: Login Failed -> %s", t.getLocalizedMessage()));
            }
        });
    }
}
