package com.rowem.ifree.sdk.sample;

import android.content.Context;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

import okhttp3.OkHttpClient;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Retrofit;
import retrofit2.converter.gson.GsonConverterFactory;
import retrofit2.http.Body;
import retrofit2.http.POST;

public class Server {

    interface API {
        @POST("/partner-echo/passikey/login")
        Call<RespLogin> login(@Body Map<String, String> body);
    }


    private static Server INSTANCE;

    public static synchronized Server getInstance(Context context){
        if(INSTANCE == null){
            INSTANCE = new Server(context);
        }
        return INSTANCE;
    }

    private API api;

    private Server(Context context) {
        Retrofit retro = new Retrofit.Builder()
                .baseUrl(BuildConfig.HOST)
                .client(buildOkHttpClient(context))
                .addConverterFactory(GsonConverterFactory.create())
                .build();
        api = retro.create(API.class);
    }

    private OkHttpClient buildOkHttpClient(Context context) {
        OkHttpClient.Builder builder = new OkHttpClient.Builder()
                .connectTimeout(30, TimeUnit.SECONDS)
                .readTimeout(30, TimeUnit.SECONDS)
                .writeTimeout(30, TimeUnit.SECONDS)
                .retryOnConnectionFailure(true)
                .addInterceptor(chain -> chain.proceed(chain.request().newBuilder()
                        .addHeader("Accept", "application/json")
                        .addHeader("Content-Type", "application/json; charset=UTF-8")
                        .build()));

        return builder.build();
    }

    /**
     * 로그인 요청
     * @param ptnToken 엑세스 토큰
     * @param callback callback
     */
    public void callApiLogin(String ptnToken, String clientId, Callback<RespLogin> callback){

        Map<String, String> body = new HashMap<>();
        body.put("ptn_token", ptnToken);
        body.put("client_id", clientId);

        api.login(body).enqueue(callback);
    }
}
